###Heard Island Collembola Individual Species Comparison with SOI###
###Comparison analysis for Chown et al. Invasive species impacts on sub-Antarctic Collembola 
###support the Antarctic climate-diversity-invasion hypothesis###

setwd("D:/")
Abun<-read.csv("Abundanal.csv",header=TRUE)
str(Abun)
library(MASS)
library(ggplot2)
library(ggthemes)
library(ggdist)
library(pscl)
library(lmtest)
library(plyr)
library(DescTools)


###Does total abundance vary among islands?###
modelc1<-glm(Abun$Total~Abun$Island+Abun$Vegsim,quasipoisson)
summary(modelc1)

modelc2<-glm.nb(Total~Island+Vegsim,data=Abun, link = log)
summary(modelc2)

Totalmeans<-ddply(Abun, c("Island"), summarise,
                  N = length(Total),
                  mean = mean(Total),
                  sd = sd(Total),
                  median=median(Total),
                  max = max(Total),
                  min = min(Total))


Totalpl1<-ggplot(Abun, aes(x=Island, y=Total,color=Island)) + 
  theme_bw() + theme(legend.position='none') + 
  scale_x_discrete(guide = guide_axis (n.dodge = 1)) +
  geom_boxplot(
    width = .25, 
    outlier.shape = NA
  ) +
  geom_point(
    size = 1.3,
    alpha = .3,
    position = position_jitter(
      seed = 1, width = .1
    )
  ) + 
  coord_cartesian(xlim = c(1.2, NA), clip = "off")
Totalpl1
Totalpl1+labs(y=bquote('Mean total density '~ (no.m^-2)), x = "Island")


###Obviously Macquarie is an outlier with TT and SC driving that###

###So provide a dataset without these two extreme sites###
Abun2<-Abun[!(Abun$Vegetation=="Stilbocarpa" | Abun$Vegetation=="Talltussock"),]
Abun2

##Recheck##
modelc3<-glm(Abun2$Total~Abun2$Island+Abun2$Vegsim,quasipoisson)
summary(modelc3)

modelc4<-glm.nb(Total~Island+Vegsim,data=Abun2,link=log)
summary(modelc4)

Totalpl2<-ggplot(Abun2, aes(x=Island, y=Total,color=Island)) + 
  theme_bw() + theme(legend.position='none') + 
  scale_x_discrete(guide = guide_axis (n.dodge = 1)) +
  geom_boxplot(
    width = .25, 
    outlier.shape = NA
  ) +
  geom_point(
    size = 1.3,
    alpha = .3,
    position = position_jitter(
      seed = 1, width = .1
    )
  ) + 
  coord_cartesian(xlim = c(1.2, NA), clip = "off")
Totalpl2
Totalpl2+labs(y=bquote('Mean total density '~ (no.m^-2)), x = "Island")


###Now recheck without fellfield since it is not similar across islands###
Abun3<-Abun[!(Abun$Vegsim=="Fellfield"),]

##Recheck##
modelc6<-glm.nb(Total~Island+Vegsim,data=Abun3, link = log)
summary(modelc6)

modelc7<-glm.nb(Indig~Island+Vegsim,data=Abun3, link = log)
summary(modelc7)

Totalpl3<-ggplot(Abun3, aes(x=Island, y=Total,color=Island)) + 
  theme_bw() + theme(legend.position='none') + 
  scale_x_discrete(guide = guide_axis (n.dodge = 1)) +
  geom_boxplot(
    width = .25, 
    outlier.shape = NA
  ) +
  geom_point(
    size = 1.3,
    alpha = .3,
    position = position_jitter(
      seed = 1, width = .1
    )
  ) + 
  coord_cartesian(xlim = c(1.2, NA), clip = "off")
Totalpl3
Totalpl3+labs(y=bquote('Mean total density '~ (no.m^-2)), x = "Island")


###Now check without macquarie two extreme sites###
Abun4<-Abun3[!(Abun3$Vegetation=="Stilbocarpa" | Abun3$Vegetation=="Talltussock"),]
Abun4

modelc8<-glm.nb(Total~Island+Vegsim,data=Abun4,link = log)
summary(modelc8)

Totalpl4<-ggplot(Abun4, aes(x=Island, y=Total,color=Island)) + 
  theme_bw() + theme(legend.position='none') + 
  scale_x_discrete(guide = guide_axis (n.dodge = 1)) +
  geom_boxplot(
    width = .25, 
    outlier.shape = NA
  ) +
  geom_point(
    size = 1.3,
    alpha = .3,
    position = position_jitter(
      seed = 1, width = .1
    )
  ) + 
  coord_cartesian(xlim = c(1.2, NA), clip = "off")
Totalpl4
Totalpl4+labs(y=bquote('Mean total density '~ (no.m^-2)), x = "Island")


###C. antarcticus abundance analysis###
rcant<-glm(Cantarcticus~Islinv+Altitude+Vegsim,data=Abun3,quasipoisson)
summary(rcant)

rcant2<-glm.nb(Cantarcticus~Islinv+Vegsim+Altitude,data=Abun3,link=log)
summary(rcant3)
warnings()

Abun3$Logcant<-log10(Abun3$Cantarcticus+1)

Cantplot<-ggplot(Abun3, aes(x=Islinv, y=Logcant,color=Islinv)) + 
  theme_bw() + theme(legend.position='none') + 
  scale_x_discrete(guide = guide_axis (n.dodge = 1)) +
  geom_boxplot(
    width = .25, 
    outlier.shape = NA
  ) +
  geom_point(
    size = 1.3,
    alpha = .3,
    position = position_jitter(
      seed = 1, width = .1
    )
  ) + 
  coord_cartesian(xlim = c(1.2, NA), clip = "off")
Cantplot
Cantplot+ylab("Log density")+xlab("Invaded")

Cantmeans<-ddply(Abun3, c("Islinv"), summarise,
                 N = length(Cantarcticus),
                 mean = mean(Cantarcticus),
                 sd = sd(Cantarcticus),
                 median=median(Cantarcticus),
                 max = max(Cantarcticus),
                 min = min(Cantarcticus))

###MedianCIs###
AbunHI<-Abun3[(Abun3$Island=="Heard"),]
str(AbunHI)
AbunInvI<-Abun3[!(Abun3$Island=="Heard"),]
str(AbunInvI)
CantCIHI<-MedianCI(AbunHI$Cantarcticus, conf.level = 0.95,
                 na.rm = FALSE, method="exact",R = 10000)
CantCIHI
CantCIII<-MedianCI(AbunInvI$Cantarcticus, conf.level = 0.95,
                   na.rm = FALSE, method="exact",R = 10000)
CantCIII

###Tullbergia bisetosa###
tbis<-glm(Tbisetosa~Islinv+Altitude+Vegsim,data=Abun3,quasipoisson)
summary(tbis)

tbis2<-glm(Tbisetosa~Islinv+Vegsim,data=Abun3,quasipoisson)
summary(tbis2)

tbis3<-glm(Tbisetosa~Islinv,data=Abun3,quasipoisson)
summary(tbis3)

tbis4<-glm.nb(Tbisetosa~Islinv+Altitude+Vegsim,data=Abun3,link=log)
summary(tbis4)

tbis5-glm.nb(Tbisetosa~Islinv+Vegsim,data=Abun3,link=log)
summary(tbis5)

tbis6<-glm.nb(Tbisetosa~Islinv,data=Abun3,link=log)
summary(tbis6)

Abun3$Logtbis<-log10(Abun3$Tbisetosa+1)

Tbisplot<-ggplot(Abun3, aes(x=Islinv, y=Logtbis,color=Islinv)) + 
  theme_bw() + theme(legend.position='none') + 
  scale_x_discrete(guide = guide_axis (n.dodge = 1)) +
  geom_boxplot(
    width = .25, 
    outlier.shape = NA
  ) +
  geom_point(
    size = 1.3,
    alpha = .3,
    position = position_jitter(
      seed = 1, width = .1
    )
  ) + 
  coord_cartesian(xlim = c(1.2, NA), clip = "off")
Tbisplot
Tbisplot+ylab("Log density")+xlab("Invaded")

Tbismeans<-ddply(Abun3, c("Islinv"), summarise,
                 N = length(Tbisetosa),
                 mean = mean(Tbisetosa),
                 sd = sd(Tbisetosa),
                 median=median(Tbisetosa),
                 max = max(Tbisetosa),
                 min = min(Tbisetosa))

TbisCIHI<-MedianCI(AbunHI$Tbisetosa, conf.level = 0.95,
                   na.rm = FALSE, method="exact",R = 10000)
TbisCIHI
TbisCIII<-MedianCI(AbunInvI$Tbisetosa, conf.level = 0.95,
                   na.rm = FALSE, method="exact",R = 10000)
TbisCIII

###Mucrosomia caeca###
mcaec<-glm(Mcaeca~Islinv+Altitude+Vegsim,data=Abun3,quasipoisson)
summary(mcaec)

mcaec2<-glm.nb(Mcaeca~Islinv+Altitude+Vegsim,data=Abun3,link=log)
summary(mcaec2)
warnings()

Abun3$Logmcaec<-log10(Abun3$Mcaeca+1)

Mcaecplot<-ggplot(Abun3, aes(x=Islinv, y=Logmcaec,color=Islinv)) + 
  theme_bw() + theme(legend.position='none') + 
  scale_x_discrete(guide = guide_axis (n.dodge = 1)) +
  geom_boxplot(
    width = .25, 
    outlier.shape = NA
  ) +
  geom_point(
    size = 1.3,
    alpha = .3,
    position = position_jitter(
      seed = 1, width = .1
    )
  ) + 
  coord_cartesian(xlim = c(1.2, NA), clip = "off")
Mcaecplot
Mcaecplot+ylab("Log density")+xlab("Invaded")

Mcaecameans<-ddply(Abun3, c("Islinv"), summarise,
                 N = length(Mcaeca),
                 mean = mean(Mcaeca),
                 sd = sd(Mcaeca),
                 median=median(Mcaeca),
                 max = max(Mcaeca),
                 min = min(Mcaeca))

McaecCIHI<-MedianCI(AbunHI$Mcaeca, conf.level = 0.95,
                   na.rm = FALSE, method="exact",R = 10000)
McaecCIHI
McaecCIII<-MedianCI(AbunInvI$Mcaeca, conf.level = 0.95,
                   na.rm = FALSE, method="exact",R = 10000)
McaecCIII

####
